skbuild package
===============

.. automodule:: skbuild
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    skbuild.command
    skbuild.platform_specifics
    skbuild.utils

Submodules
----------

skbuild.cmaker module
---------------------

.. automodule:: skbuild.cmaker
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.compat module
---------------------

.. automodule:: skbuild.compat
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.constants module
------------------------

.. automodule:: skbuild.constants
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.exceptions module
-------------------------

.. automodule:: skbuild.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.setuptools\_wrap module
-------------------------------

.. automodule:: skbuild.setuptools_wrap
    :members:
    :undoc-members:
    :show-inheritance:


